/* -*- Mode: C++; tab-width: 4; indent-tabs-mode: nil; c-basic-offset: 4 -*- */
/* ***** BEGIN LICENSE BLOCK *****
 * Version: MPL 1.1/GPL 2.0/LGPL 2.1
 *
 * The contents of this file are subject to the Mozilla Public License Version
 * 1.1 (the "License"); you may not use this file except in compliance with
 * the License. You may obtain a copy of the License at
 * http://www.mozilla.org/MPL/
 *
 * Software distributed under the License is distributed on an "AS IS" basis,
 * WITHOUT WARRANTY OF ANY KIND, either express or implied. See the License
 * for the specific language governing rights and limitations under the
 * License.
 *
 * The Original Code is mozilla.org code.
 *
 * The Initial Developer of the Original Code is Sun Microsystems.
 * Portions created by the Initial Developer are Copyright (C) 2003
 * the Initial Developer. All Rights Reserved.
 *
 * Contributor(s):
 *   Pete Zha <pete.zha@sun.com> (original author)
 *
 * Alternatively, the contents of this file may be used under the terms of
 * either the GNU General Public License Version 2 or later (the "GPL"), or
 * the GNU Lesser General Public License Version 2.1 or later (the "LGPL"),
 * in which case the provisions of the GPL or the LGPL are applicable instead
 * of those above. If you wish to allow use of your version of this file only
 * under the terms of either the GPL or the LGPL, and not to allow others to
 * use your version of this file under the terms of the MPL, indicate your
 * decision by deleting the provisions above and replace them with the notice
 * and other provisions required by the GPL or the LGPL. If you do not delete
 * the provisions above, a recipient may use your version of this file under
 * the terms of any one of the MPL, the GPL or the LGPL.
 *
 * ***** END LICENSE BLOCK ***** */

#include "nsIArray.idl"
#include "nsIFile.idl"

%{C++
#define NS_JVMCONFIGMANAGER_CID                      \
{ /* 4a68cee9-6f07-4950-b441-a1ce6a082e2f */         \
    0x4a68cee9,                                      \
    0x6f07,                                          \
    0x4950,                                          \
    {0xb4, 0x41, 0xa1, 0xce, 0x6a, 0x08, 0x2e, 0x2f} \
}
%}
/**
 * This interface contains information for the Java installation.
 */
[scriptable, uuid(3e333e20-b190-42d8-b993-d5fa435e46c4)]
interface nsIJVMConfig : nsISupports {
    readonly attribute AString version;
    readonly attribute AString type;
    readonly attribute AString OS;
    readonly attribute AString arch;
    readonly attribute nsIFile path;
    readonly attribute nsIFile mozillaPluginPath;
    readonly attribute AString description;
};

/**
 * This interface is a manager that can get information about Java
 * installations.
 */
[scriptable, uuid(ca29fff1-a677-493c-9d80-3dc60432212b)]
interface nsIJVMConfigManager : nsISupports {
    /**
     * This function returns a list of existing Java installations.
     */
    nsIArray getJVMConfigList();

    /**
     * This function tells the browser to use a specific Java installation.
     */
    void setCurrentJVMConfig(in nsIJVMConfig jvmConfig);
};

